@@ -151,6 +151,8 @@ class ExceptionReporter:
                 frames,
             'request':
                 self.request,
+            'context':
+                self.context,
             'request_meta':
                 self.filter.get_safe_request_meta(self.request),
             'filtered_POST_items':
@@ -401,13 +403,13 @@ class ExceptionHandler:
         return self.__reporter.get_lambda_response()
 
 
-def handle_exceptions(is_lambda: bool = False, return_only_html: bool = False,
+def handle_exceptions(is_lambda: bool = False, save: bool = True,
                       exceptions_folder: str = None, exclude: str = None, only_last: bool = True):
     """Organize and coordinate reporting on exceptions.
 
     Args:
         is_lambda (bool, optional): Set true if you want to handle lambda function. Defaults to False.
-        return_only_html (bool, optional): Set true if you want the function to return html. Defaults to False.
+        save (bool, optional): Set true if you want the function to save html. Defaults to True.
         exceptions_folder (str, optional): Sets the exceptions folder. Defaults to working_directory/handled_exceptions.
         exclude (str, optional): Determines which part of stacktrace to exclude. Defaults to None.
         only_last (bool, optional): Determines whether only last report should be saved. Defaults to True.
@@ -422,10 +424,9 @@ def handle_exceptions(is_lambda: bool = False, return_only_html: bool = False,
                 return function(*args, **kwargs)
             except Exception:  # noqa
                 if is_lambda:
-                    return ExceptionHandler(exclude=exclude).get_traceback_lambda()
-                elif return_only_html:
-                    return ExceptionHandler(exclude=exclude).get_traceback_html()
-                else:
+                    return ExceptionHandler(*args[:2], exclude=exclude).get_traceback_lambda()
+                html = ExceptionHandler(exclude=exclude).get_traceback_html()
+                if save:
                     time_string = datetime.now().strftime(r"%d-%m-%Y_%H-%M-%S")
                     file_name = f'handled_exception_{time_string}.html'
                     folder = exceptions_folder
@@ -440,14 +441,13 @@ def handle_exceptions(is_lambda: bool = False, return_only_html: bool = False,
                             path_to_file = os.path.join(folder, file)
                             os.remove(path_to_file)
                     file_path = os.path.join(folder, file_name)
-                    html = ExceptionHandler(exclude=exclude).get_traceback_html()
                     try:
                         with open(file_path, "w") as f:
                             f.write(html)
                         logging.warning(f'Handled exception: \nfile://{file_path}')
                     except Exception as e:
                         raise OSError('Failed to save file while handling exception: \n' + str(e))
-                    return html
+                return html
 
         return wrapper
 
